Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(180)

Unified Diff: third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp

Issue 2437803002: Relax '*' in CSPSourceList to match the FTP protocol. (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/frame/csp/CSPSourceListTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp
diff --git a/third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp b/third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp
index 328bafc244d64beabde5e86ef13eb3526d6dc117..471f6fba7a7ea30aad8138be5c04c5411288c4c9 100644
--- a/third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp
+++ b/third_party/WebKit/Source/core/frame/csp/CSPSourceList.cpp
@@ -47,11 +47,11 @@ CSPSourceList::CSPSourceList(ContentSecurityPolicy* policy, const String& direct
bool CSPSourceList::matches(const KURL& url, ResourceRequest::RedirectStatus redirectStatus) const
{
// Wildcards match network schemes ('http', 'https', 'ws', 'wss'), and the scheme of the
// protected resource: https://w3c.github.io/webappsec-csp/#match-url-to-source-expression.
// Other schemes, including custom schemes, must be explicitly listed in a source list.
if (m_allowStar) {
- if (url.protocolIsInHTTPFamily() || url.protocolIs("ws") || url.protocolIs("wss") || m_policy->protocolMatchesSelf(url))
+ if (url.protocolIsInHTTPFamily() || url.protocolIs("ftp") || url.protocolIs("ws") || url.protocolIs("wss") || m_policy->protocolMatchesSelf(url))
return true;
return hasSourceMatchInList(url, redirectStatus);
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/frame/csp/CSPSourceListTest.cpp » ('j') | no next file with comments »
@@ -47,11 +47,11 @@ CSPSourceList::CSPSourceList(ContentSecurityPolicy* policy, const String& direct
bool CSPSourceList::matches(const KURL& url, ResourceRequest::RedirectStatus redirectStatus) const
{
- // Wildcards match network schemes ('http', 'https', 'ws', 'wss'), and the scheme of the
+ // Wildcards match network schemes ('http', 'https', 'ftp', 'ws', 'wss'), and the scheme of the
// protected resource: https://w3c.github.io/webappsec-csp/#match-url-to-source-expression.
// Other schemes, including custom schemes, must be explicitly listed in a source list.

Powered by Google App Engine
This is Rietveld 408576698